@@ -26,9 +26,10 @@ class NotebookExporter(Exporter):
         return '.ipynb'
 
     output_mimetype = 'application/json'
+    export_from_notebook = "Notebook"
 
     def from_notebook_node(self, nb, resources=None, **kw):
-        nb_copy, resources = super(NotebookExporter, self).from_notebook_node(nb, resources, **kw)
+        nb_copy, resources = super().from_notebook_node(nb, resources, **kw)
         if self.nbformat_version != nb_copy.nbformat:
             resources['output_suffix'] = '.v%i' % self.nbformat_version
         else:
