@@ -53,23 +53,6 @@ class TestLatexExporter(ExportersTestsBase):
         assert len(output) > 0
 
 
-    @onlyif_cmds_exist('pandoc')
-    def test_export_basic(self):
-        """
-        Can a LatexExporter export using 'article' template?
-        """
-        (output, resources) = LatexExporter(template_file='article').from_filename(self._get_notebook())
-        assert len(output) > 0
-
-
-    @onlyif_cmds_exist('pandoc')
-    def test_export_article(self):
-        """
-        Can a LatexExporter export using 'article' template?
-        """
-        (output, resources) = LatexExporter(template_file='article').from_filename(self._get_notebook())
-        assert len(output) > 0
-
     @onlyif_cmds_exist('pandoc')
     def test_very_long_cells(self):
         """
@@ -104,7 +87,7 @@ class TestLatexExporter(ExportersTestsBase):
             with open(nbfile, 'w') as f:
                 write(nb, f, 4)
 
-            (output, resources) = LatexExporter(template_file='article').from_filename(nbfile)
+            (output, resources) = LatexExporter().from_filename(nbfile)
             assert len(output) > 0
 
     @onlyif_cmds_exist('pandoc')
@@ -128,12 +111,12 @@ class TestLatexExporter(ExportersTestsBase):
     def test_prompt_number_color_ipython(self):
         """
         Does LatexExporter properly format input and output prompts in color?
-        
+
         Uses an in memory latex template to load style_ipython as the cell style.
         """
         my_loader_tplx = DictLoader({'my_template': 
-            """
-            ((* extends 'style_ipython.tplx' *))
+            r"""
+            ((* extends 'style_ipython.tex.j2' *))
 
             ((* block docclass *))
             \documentclass[11pt]{article}
@@ -184,7 +167,7 @@ class TestLatexExporter(ExportersTestsBase):
         # Loads in an in memory latex template (.tplx) using jinja2.DictLoader
         # creates a class that uses this template with the template_file argument
         # converts an empty notebook using this mechanism
-        my_loader_tplx = DictLoader({'my_template': "{%- extends 'article.tplx' -%}"})
+        my_loader_tplx = DictLoader({'my_template': "{%- extends 'index' -%}"})
 
         class MyExporter(LatexExporter):
             template_file = 'my_template'
