@@ -6,11 +6,14 @@ Module with tests for templateexporter.py
 # Distributed under the terms of the Modified BSD License.
 
 import os
+import json
 
 from traitlets import default
 from traitlets.config import Config
 from jinja2 import DictLoader, TemplateNotFound
 from nbformat import v4
+from unittest.mock import patch
+from concurrent.futures import ProcessPoolExecutor
 
 from .base import ExportersTestsBase
 from .cheese import CheesePreprocessor
@@ -22,12 +25,24 @@ from testpath import tempdir
 
 import pytest
 
-raw_template = """{%- extends 'rst.tpl' -%}
+raw_template = """{%- extends 'index.rst.j2' -%}
 {%- block in_prompt -%}
 blah
 {%- endblock in_prompt -%}
 """
 
+class SampleExporter(TemplateExporter):
+    """
+    Exports a Python code file.
+    """
+    @default('file_extension')
+    def _file_extension_default(self):
+        return '.py'
+
+    @default('template_name')
+    def _template_name_default(self):
+        return 'python'
+
 class TestExporter(ExportersTestsBase):
     """Contains test functions for exporter.py"""
 
@@ -103,9 +118,18 @@ class TestExporter(ExportersTestsBase):
         assert resources is not None
         assert resources['cheese'] == 'real'
 
+    def test_pickle(self):
+        """
+        Can exporters be pickled & called across processes?
+        """
+        exporter = self._make_exporter()
+        executor = ProcessPoolExecutor()
+        (output, resources) = executor.submit(exporter.from_filename, self._get_notebook()).result()
+        assert len(output) > 0
+
     def test_absolute_template_file(self):
         with tempdir.TemporaryDirectory() as td:
-            template = os.path.join(td, 'abstemplate.tpl')
+            template = os.path.join(td, 'abstemplate.ext.j2')
             test_output = 'absolute!'
             with open(template, 'w') as f:
                 f.write(test_output)
@@ -113,20 +137,165 @@ class TestExporter(ExportersTestsBase):
             config.TemplateExporter.template_file = template
             exporter = self._make_exporter(config=config)
             assert exporter.template.filename == template
-            assert os.path.dirname(template) in exporter.template_path
+            assert os.path.dirname(template) in exporter.template_paths
 
     def test_relative_template_file(self):
         with tempdir.TemporaryWorkingDirectory() as td:
-            os.mkdir('relative')
-            template = os.path.abspath(os.path.join(td, 'relative', 'relative_template.tpl'))
-            test_output = 'relative!'
+            with patch('os.getcwd', return_value=os.path.abspath(td)):
+                template = os.path.join('relative', 'relative_template.ext.j2')
+                template_abs = os.path.abspath(os.path.join(td, template))
+                os.mkdir(os.path.dirname(template_abs))
+                test_output = 'relative!'
+                with open(template_abs, 'w') as f:
+                    f.write(test_output)
+                config = Config()
+                config.TemplateExporter.template_file = template
+                exporter = self._make_exporter(config=config)
+                assert os.path.abspath(exporter.template.filename) == template_abs
+                assert os.path.dirname(template_abs) in [os.path.abspath(d) for d in exporter.template_paths]
+
+    def test_absolute_template_file_compatibility(self):
+        with tempdir.TemporaryDirectory() as td:
+            template = os.path.join(td, 'abstemplate.tpl')
+            test_output = 'absolute!'
             with open(template, 'w') as f:
                 f.write(test_output)
             config = Config()
             config.TemplateExporter.template_file = template
+            with pytest.warns(DeprecationWarning):
+                exporter = self._make_exporter(config=config)
+            assert exporter.template.filename == template
+            assert os.path.dirname(template) in exporter.template_paths
+
+    def test_relative_template_file_compatibility(self):
+        with tempdir.TemporaryWorkingDirectory() as td:
+            with patch('os.getcwd', return_value=os.path.abspath(td)):
+                template = os.path.join('relative', 'relative_template.tpl')
+                template_abs = os.path.abspath(os.path.join(td, template))
+                os.mkdir(os.path.dirname(template_abs))
+                test_output = 'relative!'
+                with open(template_abs, 'w') as f:
+                    f.write(test_output)
+                config = Config()
+                config.TemplateExporter.template_file = template
+                with pytest.warns(DeprecationWarning):
+                    exporter = self._make_exporter(config=config)
+                assert os.path.abspath(exporter.template.filename) == template_abs
+                assert os.path.dirname(template_abs) in [os.path.abspath(d) for d in exporter.template_paths]
+
+    def test_absolute_template_name_tpl_compatibility(self):
+        with tempdir.TemporaryDirectory() as td:
+            template = os.path.join(td, 'abstemplate.tpl')
+            test_output = 'absolute!'
+            with open(template, 'w') as f:
+                f.write(test_output)
+            config = Config()
+            # We're setting the template_name instead of the template_file
+            config.TemplateExporter.template_name = template
+            with pytest.warns(DeprecationWarning):
+                exporter = self._make_exporter(config=config)
+            assert exporter.template.filename == template
+            assert os.path.dirname(template) in exporter.template_paths
+    
+    # Can't use @pytest.mark.parametrize without removing all self.assert calls in all tests... repeating some here
+    def absolute_template_name_5x_compatibility_test(self, template, mimetype=None):
+        config = Config()
+        # We're setting the template_name instead of the template_file
+        config.TemplateExporter.template_name = template
+        with pytest.warns(DeprecationWarning):
             exporter = self._make_exporter(config=config)
-            assert os.path.abspath(exporter.template.filename) == template
-            assert os.path.dirname(template) in [os.path.abspath(d) for d in exporter.template_path]
+        template_dir, template_file = os.path.split(exporter.template.filename)
+        _, compat_dir = os.path.split(template_dir)
+        assert compat_dir == 'compatibility'
+        assert template_file == template + '.tpl'
+        assert template_dir in exporter.template_paths
+
+    def test_absolute_template_name_5x_compatibility_full(self):
+        self.absolute_template_name_5x_compatibility_test('full', 'text/html')
+
+    def test_absolute_template_name_5x_compatibility_display_priority(self):
+        self.absolute_template_name_5x_compatibility_test('display_priority')
+
+    # Can't use @pytest.mark.parametrize without removing all self.assert calls in all tests... repeating some here
+    def relative_template_test(self, template):
+        with tempdir.TemporaryWorkingDirectory() as td:
+            with patch('os.getcwd', return_value=os.path.abspath(td)):
+                template_abs = os.path.abspath(os.path.join(td, template))
+                dirname = os.path.dirname(template_abs)
+                if not os.path.exists(dirname):
+                    os.mkdir(dirname)
+                test_output = 'relative!'
+                with open(template_abs, 'w') as f:
+                    f.write(test_output)
+                config = Config()
+                # We're setting the template_name instead of the template_file
+                config.TemplateExporter.template_name = template
+                with pytest.warns(DeprecationWarning):
+                    exporter = self._make_exporter(config=config)
+                assert os.path.abspath(exporter.template.filename) == template_abs
+                assert os.path.dirname(template_abs) in [os.path.abspath(d) for d in exporter.template_paths]
+
+    def test_relative_template_name_tpl_compatibility_local(self):
+        self.relative_template_test('relative_template.tpl')
+
+    def test_relative_template_name_tpl_compatibility_nested(self):
+        self.relative_template_test(os.path.join('relative', 'relative_template.tpl'))
+
+    def test_relative_template_name_tpl_compatibility_dot(self):
+        self.relative_template_test(os.path.join('.', 'relative_template.tpl'))
+
+    def test_relative_template_name_tpl_compatibility_dot_nested(self):
+        self.relative_template_test(os.path.join('.', 'relative', 'relative_template.tpl'))
+
+    def test_absolute_template_dir(self):
+        with tempdir.TemporaryDirectory() as td:
+            template = 'mytemplate'
+            template_file = os.path.join(td, template, 'index.py.j2')
+            template_dir = os.path.dirname(template_file)
+            os.mkdir(template_dir)
+            test_output = 'absolute!'
+            with open(template_file, 'w') as f:
+                f.write(test_output)
+            config = Config()
+            config.TemplateExporter.template_name = template
+            config.TemplateExporter.extra_template_basedirs = [td]
+            exporter = self._make_exporter(config=config)
+            assert exporter.template.filename == template_file
+            assert exporter.template_name == template
+            assert os.path.join(td, template) in exporter.template_paths
+
+    def test_local_template_dir(self):
+        with tempdir.TemporaryWorkingDirectory() as td:
+            with patch('os.getcwd', return_value=os.path.abspath(td)):
+                template = 'mytemplate'
+                template_file = os.path.join(template, 'index.py.j2')
+                template_abs = os.path.abspath(os.path.join(td, template_file))
+                template_conf = os.path.abspath(os.path.join(td, template, 'conf.json'))
+                os.mkdir(os.path.dirname(template_abs))
+                test_output = 'local!'
+                with open(template_abs, 'w') as f:
+                    f.write(test_output)
+                with open(template_conf, 'w') as f:
+                    # Mimic having a superset of accepted mimetypes
+                    f.write(json.dumps(Config(mimetypes={
+                            "text/x-python": True,
+                            "text/html": True,
+                        }
+                    )))
+                config = Config()
+                config.TemplateExporter.template_name = template
+                exporter = self._make_exporter(config=config)
+                assert os.path.abspath(exporter.template.filename) == template_abs
+                assert exporter.template_name == template
+                assert os.path.join(td, template) in exporter.template_paths
+
+    def test_local_template_file_extending_lab(self):
+        template_file = os.path.join(self._get_files_path(), 'lablike.html.j2')
+        exporter = HTMLExporter(template_file=template_file, template_name='lab')
+        nb = v4.new_notebook()
+        nb.cells.append(v4.new_code_cell("some_text"))
+        output, resources = exporter.from_notebook_node(nb)
+        assert "UNIQUE" in output
 
 
     def test_raw_template_attr(self):
@@ -140,7 +309,7 @@ class TestExporter(ExportersTestsBase):
         class AttrExporter(TemplateExporter):
             raw_template = raw_template
 
-        exporter_attr = AttrExporter()
+        exporter_attr = AttrExporter(template_name='rst')
         output_attr, _ = exporter_attr.from_notebook_node(nb)
         assert "blah" in output_attr
 
@@ -163,7 +332,7 @@ class TestExporter(ExportersTestsBase):
         output_init, _ = exporter_init.from_notebook_node(nb)
         assert "blah" in output_init
         exporter_init.raw_template = ''
-        assert exporter_init.template_file == "rst.tpl"
+        assert exporter_init.template_file == "index.rst.j2"
         output_init, _ = exporter_init.from_notebook_node(nb)
         assert "blah" not in output_init
 
@@ -178,19 +347,19 @@ class TestExporter(ExportersTestsBase):
         nb.cells.append(v4.new_code_cell("some_text"))
 
         class AttrDynamicExporter(TemplateExporter):
-            @default('template_file')
+            @default('default_template_file')
             def _template_file_default(self):
-                return "rst.tpl"
+                return "index.rst.j2"
 
             @default('raw_template')
             def _raw_template_default(self):
                 return raw_template
 
-        exporter_attr_dynamic = AttrDynamicExporter()
+        exporter_attr_dynamic = AttrDynamicExporter(template_name='rst')
         output_attr_dynamic, _ = exporter_attr_dynamic.from_notebook_node(nb)
         assert "blah" in output_attr_dynamic
         exporter_attr_dynamic.raw_template = ''
-        assert exporter_attr_dynamic.template_file == "rst.tpl"
+        assert exporter_attr_dynamic.template_file == "index.rst.j2"
         output_attr_dynamic, _ = exporter_attr_dynamic.from_notebook_node(nb)
         assert "blah" not in output_attr_dynamic
 
@@ -209,15 +378,15 @@ class TestExporter(ExportersTestsBase):
             def _raw_template_default(self):
                 return raw_template
 
-            @default('template_file')
+            @default('default_template_file')
             def _template_file_default(self):
-                return "rst.tpl"
+                return 'index.rst.j2'
 
-        exporter_attr_dynamic = AttrDynamicExporter()
+        exporter_attr_dynamic = AttrDynamicExporter(template_name='rst')
         output_attr_dynamic, _ = exporter_attr_dynamic.from_notebook_node(nb)
         assert "blah" in output_attr_dynamic
         exporter_attr_dynamic.raw_template = ''
-        assert exporter_attr_dynamic.template_file == "rst.tpl"
+        assert exporter_attr_dynamic.template_file == 'index.rst.j2'
         output_attr_dynamic, _ = exporter_attr_dynamic.from_notebook_node(nb)
         assert "blah" not in output_attr_dynamic
 
@@ -229,7 +398,7 @@ class TestExporter(ExportersTestsBase):
         nb = v4.new_notebook()
         nb.cells.append(v4.new_code_cell("some_text"))
 
-        output_constructor, _ = TemplateExporter(
+        output_constructor, _ = TemplateExporter(template_name='rst',
             raw_template=raw_template).from_notebook_node(nb)
         assert "blah" in output_constructor
 
@@ -239,7 +408,7 @@ class TestExporter(ExportersTestsBase):
         """
         nb = v4.new_notebook()
         nb.cells.append(v4.new_code_cell("some_text"))
-        exporter_assign = TemplateExporter()
+        exporter_assign = TemplateExporter(template_name='rst')
         exporter_assign.raw_template = raw_template
         output_assign, _ = exporter_assign.from_notebook_node(nb)
         assert "blah" in output_assign
@@ -250,7 +419,7 @@ class TestExporter(ExportersTestsBase):
         """
         nb = v4.new_notebook()
         nb.cells.append(v4.new_code_cell("some_text"))
-        exporter_reassign = TemplateExporter()
+        exporter_reassign = TemplateExporter(template_name='rst')
         exporter_reassign.raw_template = raw_template
         output_reassign, _ = exporter_reassign.from_notebook_node(nb)
         assert "blah" in output_reassign
@@ -270,7 +439,7 @@ class TestExporter(ExportersTestsBase):
         output_deassign, _ = exporter_deassign.from_notebook_node(nb)
         assert "blah" in output_deassign
         exporter_deassign.raw_template = ''
-        assert exporter_deassign.template_file == 'rst.tpl'
+        assert exporter_deassign.template_file == 'index.rst.j2'
         output_deassign, _ = exporter_deassign.from_notebook_node(nb)
         assert "blah" not in output_deassign
 
@@ -289,7 +458,7 @@ class TestExporter(ExportersTestsBase):
         output_dereassign, _ = exporter_dereassign.from_notebook_node(nb)
         assert "baz" in output_dereassign
         exporter_dereassign.raw_template = ''
-        assert exporter_dereassign.template_file == 'rst.tpl'
+        assert exporter_dereassign.template_file == 'index.rst.j2'
         output_dereassign, _ = exporter_dereassign.from_notebook_node(nb)
         assert "blah" not in output_dereassign
 
@@ -317,8 +486,8 @@ class TestExporter(ExportersTestsBase):
             }
         }
         c_no_io = Config(no_io)
-        exporter_no_io = TemplateExporter(config=c_no_io)
-        exporter_no_io.template_file = 'markdown'
+        exporter_no_io = TemplateExporter(config=c_no_io, template_name='markdown')
+        exporter_no_io.template_file = 'index.md.j2'
         nb_no_io, resources_no_io = exporter_no_io.from_filename(self._get_notebook())
 
         assert not resources_no_io['global_content_filter']['include_input']
@@ -335,8 +504,8 @@ class TestExporter(ExportersTestsBase):
             }
         }
         c_no_code = Config(no_code)
-        exporter_no_code = TemplateExporter(config=c_no_code)
-        exporter_no_code.template_file = 'markdown'
+        exporter_no_code = TemplateExporter(config=c_no_code, template_name='markdown')
+        exporter_no_code.template_file = 'index.md.j2'
         nb_no_code, resources_no_code = exporter_no_code.from_filename(self._get_notebook())
 
         assert not resources_no_code['global_content_filter']['include_code']
@@ -375,8 +544,8 @@ class TestExporter(ExportersTestsBase):
         }
 
         c_no_md = Config(no_md)
-        exporter_no_md = TemplateExporter(config=c_no_md)
-        exporter_no_md.template_file = 'python'
+        exporter_no_md = TemplateExporter(config=c_no_md, template_name='python')
+        exporter_no_md.template_file = 'index.py.j2'
         nb_no_md, resources_no_md = exporter_no_md.from_filename(self._get_notebook())
 
         assert not resources_no_md['global_content_filter']['include_markdown']
@@ -398,7 +567,7 @@ class TestExporter(ExportersTestsBase):
         nb_no_output_prompt, resources_no_output_prompt = exporter_no_output_prompt.from_filename(self._get_notebook())
 
         assert not resources_no_output_prompt['global_content_filter']['include_output_prompt']
-        assert "Out[" not in nb_no_output_prompt
+        assert "Out[1]" not in nb_no_output_prompt
 
     def test_remove_elements_with_tags(self):
 
@@ -418,10 +587,5 @@ class TestExporter(ExportersTestsBase):
         assert "(100,)" not in nb
 
     def _make_exporter(self, config=None):
-        # Create the exporter instance, make sure to set a template name since
-        # the base TemplateExporter doesn't have a template associated with it.
-        exporter = TemplateExporter(config=config)
-        if not exporter.template_file:
-            # give it a default if not specified
-            exporter.template_file = 'python'
-        return exporter
+        exporter = SampleExporter(config=config)
+        return exporter
\ No newline at end of file
