@@ -29,8 +29,8 @@ from nbconvert.filters.strings import add_anchor
 
 
 class MathBlockGrammar(mistune.BlockGrammar):
-    """This defines a single regex comprised of the different patterns that 
-    identify math content spanning multiple lines. These are used by the 
+    """This defines a single regex comprised of the different patterns that
+    identify math content spanning multiple lines. These are used by the
     MathBlockLexer.
     """
     multi_math_str = "|".join([r"^\$\$.*?\$\$",
@@ -40,17 +40,17 @@ class MathBlockGrammar(mistune.BlockGrammar):
 
 
 class MathBlockLexer(mistune.BlockLexer):
-    """ This acts as a pass-through to the MathInlineLexer. It is needed in 
-    order to avoid other block level rules splitting math sections apart. 
+    """ This acts as a pass-through to the MathInlineLexer. It is needed in
+    order to avoid other block level rules splitting math sections apart.
     """
-    
+
     default_rules = (['multiline_math']
                      + mistune.BlockLexer.default_rules)
 
     def __init__(self, rules=None, **kwargs):
         if rules is None:
             rules = MathBlockGrammar()
-        super(MathBlockLexer, self).__init__(rules, **kwargs)
+        super().__init__(rules, **kwargs)
 
     def parse_multiline_math(self, m):
         """Add token to pass through mutiline math."""
@@ -61,7 +61,7 @@ class MathBlockLexer(mistune.BlockLexer):
 
 
 class MathInlineGrammar(mistune.InlineGrammar):
-    """This defines different ways of declaring math objects that should be 
+    """This defines different ways of declaring math objects that should be
     passed through to mathjax unaffected. These are used by the MathInlineLexer.
     """
     inline_math = re.compile(r"^\$(.+?)\$|^\\\\\((.+?)\\\\\)", re.DOTALL)
@@ -72,12 +72,12 @@ class MathInlineGrammar(mistune.InlineGrammar):
 
 
 class MathInlineLexer(mistune.InlineLexer):
-    """This interprets the content of LaTeX style math objects using the rules 
-    defined by the MathInlineGrammar. 
-    
-    In particular this grabs ``$$...$$``, ``\\[...\\]``, ``\\(...\\)``, ``$...$``, 
-    and ``\begin{foo}...\end{foo}`` styles for declaring mathematics. It strips 
-    delimiters from all these varieties, and extracts the type of environment 
+    r"""This interprets the content of LaTeX style math objects using the rules
+    defined by the MathInlineGrammar.
+
+    In particular this grabs ``$$...$$``, ``\\[...\\]``, ``\\(...\\)``, ``$...$``,
+    and ``\begin{foo}...\end{foo}`` styles for declaring mathematics. It strips
+    delimiters from all these varieties, and extracts the type of environment
     in the last case (``foo`` in this example).
     """
     default_rules = (['block_math', 'inline_math', 'latex_environment']
@@ -86,7 +86,7 @@ class MathInlineLexer(mistune.InlineLexer):
     def __init__(self, renderer, rules=None, **kwargs):
         if rules is None:
             rules = MathInlineGrammar()
-        super(MathInlineLexer, self).__init__(renderer, rules, **kwargs)
+        super().__init__(renderer, rules, **kwargs)
 
     def output_inline_math(self, m):
         return self.renderer.inline_math(m.group(1) or m.group(2))
@@ -105,9 +105,9 @@ class MarkdownWithMath(mistune.Markdown):
             kwargs['inline'] = MathInlineLexer
         if 'block' not in kwargs:
             kwargs['block'] = MathBlockLexer
-        super(MarkdownWithMath, self).__init__(renderer, **kwargs)
+        super().__init__(renderer, **kwargs)
+
 
-    
     def output_multiline_math(self):
         return self.inline(self.token["text"])
 
@@ -129,7 +129,9 @@ class IPythonRenderer(mistune.Renderer):
         return highlight(code, lexer, formatter)
 
     def header(self, text, level, raw=None):
-        html = super(IPythonRenderer, self).header(text, level, raw=raw)
+        html = super().header(text, level, raw=raw)
+        if self.options.get("exclude_anchor_links"):
+            return html
         anchor_link_text = self.options.get('anchor_link_text', u'¶')
         return add_anchor(html, anchor_link_text=anchor_link_text)
 
@@ -166,11 +168,11 @@ class IPythonRenderer(mistune.Renderer):
                 if preferred_mime_type in attachment:
                     break
             else:  # otherwise we choose the first mimetype we can find
-                preferred_mime_types = attachment.keys()[0]
+                preferred_mime_type = list(attachment.keys())[0]
             mime_type = preferred_mime_type
             data = attachment[mime_type]
             src = 'data:' + mime_type + ';base64,' + data
-        return super(IPythonRenderer, self).image(src, title, text)
+        return super().image(src, title, text)
 
 
 def markdown2html_mistune(source):
